"""Module for annotations.

Annotations are used to mark parts of the text that are relevant for the task.
Annotations are usually extracted from previous parts of the pipeline and used
by the detectors to spot entities in the text.
"""

from dataclasses import dataclass


@dataclass
class Annotation:
    """Interface for annotations."""

    def __hash__(self) -> int:
        """Returns the hash of the annotation."""
        return (type(self), *(self.__dict__.values())).__hash__()


class MorphosyntacticAnnotation(Annotation):
    """Annotation for morphosyntactic tags."""

    def __init__(self, morphosyntactic_tag: str) -> None:
        """Initializes the annotation.

        Args:
            morphosyntactic_tag (str): Morphosyntactic tag.

        """
        self.morphosyntactic_tag = morphosyntactic_tag


@dataclass
class NerAnnotation(Annotation):
    """Annotation for named entities."""

    ner_type: str
