"""Helper module for detecting URLs."""

from typing import List

import regex as re
from regex.regex import Pattern


def generate_url_regex(exeptions: List[str]) -> Pattern:
    """Returns a regex for detecting urls.

    Args:
        exeptions (List[str]): List of strings that should not be treated as
            urls.

    Returns:
        str: a regex for detecting urls

    """
    return re.compile(
        r"\b(?:{})\b(*SKIP)(*FAIL)|".format("|".join(exeptions))
        + r"(?:(?P<protocol>(?:(?:https?|ftp):)?\/\/)?"
        r"(?P<auth>\S+(?::\S*)?@)?"
        r"(?P<host>(?!(?:10|127)(?:\.\d{1,3}){3})"
        r"(?!(?:169\.254|192\.168)(?:\.\d{1,3}){2})"
        r"(?!172\.(?:1[6-9]|2\d|3[0-1])(?:\.\d{1,3}){2})"
        r"(?:[1-9]\d?|1\d\d|2[01]\d|22[0-3])"
        r"(?:\.(?:1?\d{1,2}|2[0-4]\d|25[0-5])){2}"
        r"(?:\.(?:[1-9]\d?|1\d\d|2[0-4]\d|25[0-4]))"
        r"|"
        r"((?:[a-z0-9\u00a1-\uffff][a-z0-9\u00a1-\uffff_-]{0,62})?"
        r"[a-z0-9\u00a1-\uffff]\.)+)"
        r"(?P<tld>[a-z\u00a1-\uffff]{2,}\.??)"
        r"(?P<port>:\d{2,5})?"
        r"(?P<path>[/?#]\S*)?)",
        re.UNICODE | re.I,
    )


URL_REGEX_GENERAL = generate_url_regex([])
