"""Detector for urls."""

from typing import Any, Dict, List, Tuple

from src.detections import UrlDetection
from src.detectors.interface import Detector

from .common import generate_url_regex
from .pl import URL_REGEX_PL


class UrlDetector(Detector):
    """Detector for urls."""

    def __init__(self, language: str = "pl") -> None:
        """Initializes the detector.

        Args:
            language (str, optional): Language of analyzed texts.
                Defaults to "pl".

        """
        self._language = language

    def detect(
        self, text: str, annotations: Dict[str, List[Tuple[int, int, Any]]]
    ) -> List[Tuple[int, int, UrlDetection]]:
        """Detects urls in the text.

        Args:
            text (str): the text to be searched
            annotations (Dict[str, List[Tuple[int, int, Any]]]): Annotations of
                the text

        Returns:
            List[Tuple[int, int, UrlDetection]]: a list of tuples containing
                (start, end, entity_type)

        """
        if self._language == "pl":
            url_regex = URL_REGEX_PL
        else:
            url_regex = generate_url_regex(self._language)

        matches = url_regex.finditer(text)
        urls = []
        for match in matches:
            urls.append((match.start(), match.end(), UrlDetection()))

        return urls
