"""Module for detecting user mentions in a text."""

from typing import Any, Dict, List, Tuple

import regex as re

from src.detections import UserDetection
from src.detectors.interface import Detector


USER_REGEX = re.compile(r"\B(?P<username>\@[\w\-]+)")


class UserDetector(Detector):
    """Detector for user mentions."""

    def detect(
        self, text: str, annotations: Dict[str, List[Tuple[int, int, Any]]]
    ) -> List[Tuple[int, int, UserDetection]]:
        """Detects users in the text.

        Args:
            text (str): the text to be searched
            annotations (Dict[str, List[Tuple[int, int, Any]]]): Annotations of
                the text

        Returns:
            List[Tuple[int, int, UserDetection]]: a list of tuples containing
                (start, end, entity_type)

        """
        matches = USER_REGEX.finditer(text)
        users = []
        for match in matches:
            users.append((match.start(), match.end(), UserDetection()))

        return users
