"""Morpohosyntactic Dictionary Interface definition."""

from abc import ABC, abstractmethod
from typing import List, Optional, Type

from src.detections import Detection


class MorphosyntacticDictionary(ABC):
    """Interface for dictionaries with morphosyntactic tags.

    Dictionary allows to replace a detection with anonimized one
    while (trying to) keep the same morphosyntactic form

    Ie.: Janusza -> Marka, Januszowi -> Markowi etc.
    """

    @abstractmethod
    def get_supported_detection_classes(self) -> List[Type[Detection]]:
        """Returns a list of supported detection classess.

        Returns:
            List[Type[Detection]]: List of detection classes that are supported

        """
        pass

    def get_random_replacement(self, original_entry: Detection) -> Optional[str]:
        """Returns a random replacement of original entry.

        Args:
            original_entry (Detection): Detection that should be replaced. Class
                should have MorphosyntacticInfoMixin


        Returns:
            Optional[str]: Text that should replace the original entry

        """
        pass
