"""Module for the Suppressor interface."""

from abc import ABC, abstractmethod
from typing import Any, List, Tuple


class Suppressor(ABC):
    """Suppressor interface.

    Suppressors are used to remove overlapping annotations.
    """

    @abstractmethod
    def suppress(
        self, annotations: List[Tuple[int, int, Any]]
    ) -> List[Tuple[int, int, Any]]:
        """Suppresses annotations on overlap.

        Args:
            annotations (List[Tuple[int, int, Any]]): List of annotations.

        Returns:
            List[Tuple[int, int, Any]]: List of annotations with overlapping
                annotations removed.

        """
        raise NotImplementedError
